@@ -1450,6 +1450,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Stdlib.Sys instead"]
 
+module Type = Stdlib.Type 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Stdlib.Type instead"]
+
 module Uchar = Stdlib.Uchar 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
